@@ -1,8 +1,8 @@
-/* aide, Advanced Intrusion Detection Environment
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2002,2006 Rami Lehti, Pablo Virolainen, Richard
- * van den Berg
- * $Header$
+ * Copyright (C) 1999-2002, 2006, 2020 Rami Lehti, Pablo Virolainen,
+ *               Richard van den Berg, Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,25 +14,17 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _DB_FILE_H_INCLUDED
 #define _DB_FILE_H_INCLUDED
 
-#include "db.h"
+#include "db_config.h"
 
-extern void db_buff(int, FILE*);
-extern int db_scan(void); /* Rumaa.... */
-extern char* dbtext; /* Todella rumaa... */
-extern long* db_lineno;
-extern long db_in_lineno;
-extern long db_new_lineno;
-
-
-char** db_readline_file(int);
+char** db_readline_file(database*);
 int db_writespec_file(db_config*);
 int db_writeline_file(db_line* line,db_config* conf,url_t* url);
 int db_close_file(db_config* conf);
