@@ -1,9 +1,9 @@
-/* aide, Advanced Intrusion Detection Environment
- * vi: ts=8 sw=8
+/*
+ * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2002,2004-2006,2009-2011,2013,2018 Rami Lehti, Pablo
- * Virolainen, Mike Markley, Richard van den Berg, Hannes von Haugwitz
- * $Header$
+ * Copyright (C) 1999-2002, 2004-2006, 2009-2011, 2013, 2018-2021 Rami Lehti,
+ *               Pablo Virolainen, Mike Markley, Richard van den Berg,
+ *               Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,12 +15,13 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "aide.h"
+#include "config.h"
 
 #ifndef _POSIX_C_SOURCE
 #define _POSIX_C_SOURCE 200112L
@@ -41,13 +42,14 @@
 
 #include "db_config.h"
 #include "do_md.h"
-#include "report.h"
+#include "util.h"
+#include "log.h"
+#include "attributes.h"
 #include "list.h"
 /*for locale support*/
 #include "locale-aide.h"
 /*for locale support*/
 
-
 /* This define should be somewhere else */
 #define READ_BLOCK_SIZE 16777216
 
@@ -157,61 +159,42 @@ pid_t open_prelinked(const char * path, int * fd) {
 
 #endif
 
-void free_hashes(db_line* dl){
-
-#define free_hash(a) dl->a=NULL
-
-  free_hash(md5);
-  free_hash(sha1);
-  free_hash(rmd160);
-  free_hash(tiger);
-#ifdef WITH_MHASH
-  free_hash(crc32);
-  free_hash(haval);
-  free_hash(gost);
-  free_hash(crc32b);  
-#endif
-  free_hash(sha256);
-  free_hash(sha512);
-}
-
-int stat_cmp(struct AIDE_STAT_TYPE* f1,struct AIDE_STAT_TYPE* f2) {
+int stat_cmp(struct stat* f1,struct stat* f2) {
   if (f1==NULL || f2==NULL) {
     return RETFAIL;
   }
-#define stat_cmp_helper(n,n2) ((f1->n!=f2->n)*n2)
+#define stat_cmp_helper(n,attribute) ((f1->n!=f2->n)*ATTR(attribute))
 
-  return (stat_cmp_helper(st_ino,DB_INODE)|
-	  stat_cmp_helper(st_mode,DB_PERM)|
-	  stat_cmp_helper(st_nlink,DB_LNKCOUNT)|
-	  stat_cmp_helper(st_size,DB_SIZE)|
-	  stat_cmp_helper(st_mtime,DB_MTIME)|
-	  stat_cmp_helper(st_ctime,DB_CTIME)|
-	  stat_cmp_helper(st_blocks,DB_BCOUNT)|
-	  stat_cmp_helper(st_blksize,DB_BSIZE)|
-	  stat_cmp_helper(st_rdev,DB_RDEV)|
-	  stat_cmp_helper(st_gid,DB_GID)|
-	  stat_cmp_helper(st_uid,DB_UID)|
-	  stat_cmp_helper(st_dev,DB_DEV));
+  return (stat_cmp_helper(st_ino,attr_inode)|
+	  stat_cmp_helper(st_mode,attr_perm)|
+	  stat_cmp_helper(st_nlink,attr_linkcount)|
+	  stat_cmp_helper(st_size,attr_size)|
+	  stat_cmp_helper(st_mtime,attr_mtime)|
+	  stat_cmp_helper(st_ctime,attr_ctime)|
+	  stat_cmp_helper(st_blocks,attr_bcount)|
+	  stat_cmp_helper(st_blksize,attr_bsize)|
+	  stat_cmp_helper(st_rdev,attr_rdev)|
+	  stat_cmp_helper(st_gid,attr_gid)|
+	  stat_cmp_helper(st_uid,attr_uid)|
+	  stat_cmp_helper(st_dev,attr_dev));
 }
 
 
 void no_hash(db_line* line);
 
-void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
+void calc_md(struct stat* old_fs,db_line* line) {
   /*
     We stat after opening just to make sure that the file
     from we are about to calculate the hash is the correct one,
     and we don't read from a pipe :)
    */
-  struct AIDE_STAT_TYPE fs;
+  struct stat fs;
   int sres=0;
   int stat_diff,filedes;
 #ifdef WITH_PRELINK
   pid_t pid;
 #endif
 
-  error(255,"calc_md called\n");
 #ifdef _PARAMETER_CHECK_
   if (line==NULL) {
     abort();
@@ -227,10 +210,10 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
   if (filedes==-1) {
     char* er=strerror(errno);
     if (er!=NULL) {
-      error(3,"do_md(): open() for %s failed: %s\n",
+      log_msg(LOG_LEVEL_WARNING, "hash calculation: open() failed for %s: %s",
 	    line->fullpath,er);
     } else {
-      error(3,"do_md(): open() for %s failed: %i\n",
+      log_msg(LOG_LEVEL_WARNING, "hash calculation: open() failed for %s: %i",
 	    line->fullpath,errno);
     }
     /*
@@ -240,15 +223,16 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
     return;
   }
   
-  sres=AIDE_FSTAT_FUNC(filedes,&fs);
-  if(!(line->attr&DB_RDEV))
+  sres=fstat(filedes,&fs);
+  if (sres != 0) {
+      log_msg(LOG_LEVEL_WARNING, "hash calculation: fstat() failed for '%s': %s", line->fullpath, strerror(errno));
+  }
+  if(!(line->attr&ATTR(attr_rdev)))
 	  fs.st_rdev=0;
   
 #ifdef HAVE_POSIX_FADVISE
   if (posix_fadvise(filedes,0,fs.st_size,POSIX_FADV_NOREUSE)!=0) {
-	error(255,"posix_fadvise error %s\n",strerror(errno));
-  } else {
-	error(255,"posix_fadvise(%i,0,%li,POSIX_FADV_NOREUSE) ok\n",filedes,fs.st_size);
+    log_msg(LOG_LEVEL_DEBUG, "hash calculation: posix_fadvise error for '%s': %s", line->fullpath, strerror(errno));
   }
 #endif
   if ((stat_diff=stat_cmp(&fs,old_fs))==RETOK) {
@@ -265,7 +249,7 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
       close(filedes);
       pid = open_prelinked(line->fullpath, &filedes);
       if (pid == 0) {
-        error(0, "Error on starting prelink undo\n");
+        log_msg(LOG_LEVEL_WARNING, "hash calculation: error on starting prelink for '%s'", line->fullpath);
 	return;
       }
     }
@@ -279,7 +263,8 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
     
     mdc.todo_attr=line->attr;
     
-    if (init_md(&mdc)==RETOK) {
+    if (init_md(&mdc, line->filename)==RETOK) {
+        log_msg(LOG_LEVEL_DEBUG," calculate hashes for '%s'", line->filename);
 #ifdef HAVE_MMAP
 #ifdef WITH_PRELINK
       if (pid == 0) {
@@ -309,14 +294,14 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
 	   r_size-=MMAP_BLOCK_SIZE;
 	 }
 	 if ( buf == MAP_FAILED ) {
-	   error(0,"error mmap'ing %s: %s\n", line->fullpath,strerror(errno));
+	   log_msg(LOG_LEVEL_WARNING, "hash calculation: error mmap'ing '%s': %s", line->fullpath, strerror(errno));
 	   close(filedes);
 	   close_md(&mdc);
 	   return;
 	 }
 	 conf->catch_mmap=1;
 	 if (update_md(&mdc,buf,size)!=RETOK) {
-	   error(0,"Message digest failed during update\n");
+	   log_msg(LOG_LEVEL_WARNING, "hash calculation: update_md() failed for '%s'", line->fullpath);
 	   close(filedes);
 	   close_md(&mdc);
 	   munmap(buf,size);
@@ -334,13 +319,13 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
       }
 #endif
 #endif /* not HAVE_MMAP */
-      buf=malloc(READ_BLOCK_SIZE);
+      buf=checked_malloc(READ_BLOCK_SIZE);
 #if READ_BLOCK_SIZE>SSIZE_MAX
 #error "READ_BLOCK_SIZE" is too large. Max value is SSIZE_MAX, and current is READ_BLOCK_SIZE
 #endif
       while ((size=TEMP_FAILURE_RETRY(read(filedes,buf,READ_BLOCK_SIZE)))>0) {
 	if (update_md(&mdc,buf,size)!=RETOK) {
-	  error(0,"Message digest failed during update\n");
+	   log_msg(LOG_LEVEL_WARNING, "hash calculation: update_md() failed for '%s'", line->fullpath);
 	  close(filedes);
 	  close_md(&mdc);
 	  return;
@@ -353,7 +338,7 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
         int status;
         (void) waitpid(pid, &status, 0);
         if (!WIFEXITED(status) || WEXITSTATUS(status)) {
-          error(0, "Error on exit of prelink child process\n");
+	     log_msg(LOG_LEVEL_WARNING, "hash calculation: error on exit of prelink child process for '%s'", line->fullpath);
 	  close(filedes);
 	  close_md(&mdc);
           return;
@@ -365,26 +350,25 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
       md2line(&mdc,line);
 
     } else {
-      error(3,"Message digest initialization failed.\n");
+	  log_msg(LOG_LEVEL_WARNING, "hash calculation: init_md() failed for '%s'", line->fullpath);
       no_hash(line);
       close(filedes);
       return;
     }
   } else {
-    unsigned i;
     /*
       Something just wasn't correct, so no hash calculated.
     */
     
-    error(5,"Entry %s was changed so that hash cannot be calculated for it\n"
-	  ,line->fullpath);
-
-    for(i=0;i<db_unknown;i++) {
+      DB_ATTR_TYPE changed_attribures = 0ULL;
+    for(ATTRIBUTE i=0;i<num_attrs;i++) {
       if (((1<<i)&stat_diff)!=0) {
-	error(5,"Attribute %s has been changed\n",db_names[i]);
+          changed_attribures |= 1<<i;
       }
     }
-    
+    char *str;
+    log_msg(LOG_LEVEL_WARNING, "hash calculation: '%s' has been changed (changed attributes: %s), hash could not be calculated", line->fullpath, str = diff_attributes(0, changed_attribures));
+    free(str);
     no_hash(line);
     close(filedes);
     return;
@@ -393,17 +377,17 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
   return;
 }
 
-void fs2db_line(struct AIDE_STAT_TYPE* fs,db_line* line) {
+void fs2db_line(struct stat* fs,db_line* line) {
   
   line->inode=fs->st_ino;
 
-  if(DB_UID&line->attr) {
+  if(ATTR(attr_uid)&line->attr) {
     line->uid=fs->st_uid;
   }else {
     line->uid=0;
   }
 
-  if(DB_GID&line->attr){
+  if(ATTR(attr_gid)&line->attr){
     line->gid=fs->st_gid;
   }else{
     line->gid=0;
@@ -411,37 +395,37 @@ void fs2db_line(struct AIDE_STAT_TYPE* fs,db_line* line) {
 
   line->perm=fs->st_mode;
 
-  if(DB_SIZE&line->attr||DB_SIZEG&line->attr){
+  if(ATTR(attr_size)&line->attr||ATTR(attr_sizeg)&line->attr){
     line->size=fs->st_size;
   }else{
     line->size=0;
   }
   
-  if(DB_LNKCOUNT&line->attr){
+  if(ATTR(attr_linkcount)&line->attr){
     line->nlink=fs->st_nlink;
   }else {
     line->nlink=0;
   }
 
-  if(DB_MTIME&line->attr){
+  if(ATTR(attr_mtime)&line->attr){
     line->mtime=fs->st_mtime;
   }else{
     line->mtime=0;
   }
 
-  if(DB_CTIME&line->attr){
+  if(ATTR(attr_ctime)&line->attr){
     line->ctime=fs->st_ctime;
   }else{
     line->ctime=0;
   }
   
-  if(DB_ATIME&line->attr){
+  if(ATTR(attr_atime)&line->attr){
     line->atime=fs->st_atime;
   }else{
     line->atime=0;
   }
 
-  if(DB_BCOUNT&line->attr){
+  if(ATTR(attr_bcount)&line->attr){
     line->bcount=fs->st_blocks;
   } else {
     line->bcount=0;
@@ -454,7 +438,7 @@ void acl2line(db_line* line) {
   acl_type *ret = NULL;
   
 #ifdef WITH_POSIX_ACL
-  if(DB_ACL&line->attr) {
+  if(ATTR(attr_acl)&line->attr) {
     acl_t acl_a;
     acl_t acl_d;
     char *tmp = NULL;
@@ -462,28 +446,27 @@ void acl2line(db_line* line) {
     acl_a = acl_get_file(line->fullpath, ACL_TYPE_ACCESS);
     acl_d = acl_get_file(line->fullpath, ACL_TYPE_DEFAULT);
     if ((acl_a == NULL) && (errno == ENOTSUP)) {
-      line->attr&=(~DB_ACL);
+      line->attr&=(~ATTR(attr_acl));
       return;
     }
     if (acl_a == NULL)
-      error(0, "Tried to read access ACL on %s but failed with: %s\n",
+      log_msg(LOG_LEVEL_WARNING, "tried to read access ACL on %s but failed with: %s",
             line->fullpath, strerror(errno));
     if ((acl_d == NULL) && (errno != EACCES)) /* ignore DEFAULT on files */
     {
       acl_free(acl_a);
-      error(0, "Tried to read default ACL on %s but failed with: %s\n",
+      log_msg(LOG_LEVEL_WARNING, "tried to read default ACL on %s but failed with: %s",
             line->fullpath, strerror(errno));
     }
 
-    /* assume memory allocs work, like rest of AIDE code... */
-    ret = malloc(sizeof(acl_type));
+    ret = checked_malloc(sizeof(acl_type));
 
     /* use tmp, so free() can be called instead of acl_free() */
     tmp = acl_to_text(acl_a, NULL);
     if (!tmp || !*tmp)
       ret->acl_a = NULL;
     else
-      ret->acl_a = strdup(tmp);
+      ret->acl_a = checked_strdup(tmp);
     acl_free(tmp);
 
     if (!acl_d)
@@ -494,7 +477,7 @@ void acl2line(db_line* line) {
       if (!tmp || !*tmp)
         ret->acl_d = NULL;
       else
-        ret->acl_d = strdup(tmp);
+        ret->acl_d = checked_strdup(tmp);
       acl_free(tmp);
     }
 
@@ -503,34 +486,6 @@ void acl2line(db_line* line) {
   }
   line->acl = ret;
 #endif  
-#ifdef WITH_SUN_ACL
-  if(DB_ACL&line->attr) { /* There might be a bug here. */
-    int res;
-    line->acl=malloc(sizeof(acl_type));
-    line->acl->entries=acl(line->fullpath,GETACLCNT,0,NULL);
-    if (line->acl->entries==-1) {
-      char* er=strerror(errno);
-      line->acl->entries=0;
-      if (er==NULL) {
-	error(0,"ACL query failed for %s. strerror failed for %i\n",line->fullpath,errno);
-      } else {
-	error(0,"ACL query failed for %s:%s\n",line->fullpath,er);
-      }
-    } else {
-      line->acl->acl=malloc(sizeof(aclent_t)*line->acl->entries);
-      res=acl(line->fullpath,GETACL,line->acl->entries,line->acl->acl);
-      if (res==-1) {
-	error(0,"ACL error %s\n",strerror(errno));
-      } else {
-	if (res!=line->acl->entries) {
-	  error(0,"Tried to read %i acl but got %i\n",line->acl->entries,res);
-	}
-      }
-    }
-  }else{
-    line->acl=NULL;
-  }
-#endif
 }
 #endif
 
@@ -538,10 +493,10 @@ void acl2line(db_line* line) {
 static xattrs_type *xattr_new(void) {
     xattrs_type *ret = NULL;
 
-    ret = malloc(sizeof(xattrs_type));
+    ret = checked_malloc(sizeof(xattrs_type));
     ret->num = 0;
     ret->sz  = 2;
-    ret->ents = malloc(sizeof(xattr_node) * ret->sz);
+    ret->ents = checked_malloc(sizeof(xattr_node) * ret->sz);
 
     return (ret);
 }
@@ -550,7 +505,7 @@ static void *xzmemdup(const void *ptr, size_t len) {
     /* always keeps a 0 at the end... */
     void *ret = NULL;
 
-    ret = malloc(len+1);
+    ret = checked_malloc(len+1);
     memcpy(ret, ptr, len);
     ((char*)ret)[len] = 0;
 
@@ -561,10 +516,10 @@ static void xattr_add(xattrs_type *xattrs, const char *key, const char
         *val, size_t vsz) {
     if (xattrs->num >= xattrs->sz) {
         xattrs->sz <<= 1;
-        xattrs->ents = realloc(xattrs->ents, sizeof(xattr_node) * xattrs->sz);
+        xattrs->ents = checked_realloc(xattrs->ents, sizeof(xattr_node) * xattrs->sz);
     }
 
-    xattrs->ents[xattrs->num].key = strdup(key);
+    xattrs->ents[xattrs->num].key = checked_strdup(key);
     xattrs->ents[xattrs->num].val = xzmemdup(val, vsz);
     xattrs->ents[xattrs->num].vsz = vsz;
 
@@ -578,11 +533,10 @@ void xattrs2line(db_line *line) {
     static char *xatrs = NULL;
     ssize_t xret = -1;
 
-    if (!(DB_XATTRS&line->attr))
+    if (!(ATTR(attr_xattrs)&line->attr))
         return;
 
-    /* assume memory allocs work, like rest of AIDE code... */
-    if (!xatrs) xatrs = malloc(xsz);
+    if (!xatrs) xatrs = checked_malloc(xsz);
 
     while (((xret = llistxattr(line->fullpath, xatrs, xsz)) == -1) && (errno == ERANGE)) {
         xsz <<= 1;
@@ -590,15 +544,15 @@ void xattrs2line(db_line *line) {
     }
 
     if ((xret == -1) && ((errno == ENOSYS) || (errno == ENOTSUP))) {
-        line->attr&=(~DB_XATTRS);
+        line->attr&=(~ATTR(attr_xattrs));
     } else if (xret == -1) {
-        error(0, "listxattrs failed for %s:%s\n", line->fullpath, strerror(errno));
+        log_msg(LOG_LEVEL_WARNING, "listxattrs failed for %s:%s", line->fullpath, strerror(errno));
     } else if (xret) {
         const char *attr = xatrs;
         static ssize_t asz = 1024;
         static char *val = NULL;
 
-        if (!val) val = malloc(asz);
+        if (!val) val = checked_malloc(asz);
 
         xattrs = xattr_new();
 
@@ -620,7 +574,7 @@ void xattrs2line(db_line *line) {
             if (aret != -1)
                 xattr_add(xattrs, attr, val, aret);
             else if (errno != ENOATTR)
-                error(0, "getxattr failed for %s:%s\n", line->fullpath, strerror(errno));
+                log_msg(LOG_LEVEL_WARNING, "getxattr failed for %s:%s", line->fullpath, strerror(errno));
 
 next_attr:
             attr += len + 1;
@@ -636,17 +590,17 @@ next_attr:
 void selinux2line(db_line *line) {
     char *cntx = NULL;
 
-    if (!(DB_SELINUX&line->attr))
+    if (!(ATTR(attr_selinux)&line->attr))
         return;
 
     if (lgetfilecon_raw(line->fullpath, &cntx) == -1) {
-        line->attr&=(~DB_SELINUX);
+        line->attr&=(~ATTR(attr_selinux));
         if ((errno != ENOATTR) && (errno != EOPNOTSUPP))
-            error(0, "lgetfilecon_raw failed for %s:%s\n", line->fullpath, strerror(errno));
+            log_msg(LOG_LEVEL_WARNING, "lgetfilecon_raw failed for %s: %s", line->fullpath, strerror(errno));
         return;
     }
 
-    line->cntx = strdup(cntx);
+    line->cntx = checked_strdup(cntx);
 
     freecon(cntx);
 }
@@ -655,11 +609,11 @@ void selinux2line(db_line *line) {
 #ifdef WITH_E2FSATTRS
 void e2fsattrs2line(db_line* line) {
     unsigned long flags;
-    if (DB_E2FSATTRS&line->attr) {
+    if (ATTR(attr_e2fsattrs)&line->attr) {
         if (fgetflags(line->fullpath, &flags) == 0) {
             line->e2fsattrs=flags;
         } else {
-            line->attr&=(~DB_E2FSATTRS);
+            line->attr&=(~ATTR(attr_e2fsattrs));
             line->e2fsattrs=0;
         }
     } else {
@@ -668,7 +622,29 @@ void e2fsattrs2line(db_line* line) {
 }
 #endif
 
+#ifdef WITH_CAPABILITIES
+void capabilities2line(db_line* line) {
+    cap_t caps;
+    char *txt_caps;
+
+    if (!(ATTR(attr_capabilities)&line->attr))
+        return;
+
+    caps = cap_get_file(line->fullpath);
+
+    if (caps != NULL) {
+        txt_caps = cap_to_text(caps, NULL);
+        line->capabilities = checked_strdup(txt_caps);
+	cap_free(txt_caps);
+	cap_free(caps);
+    } else {
+        line->attr&=(~ATTR(attr_capabilities));
+        line->capabilities=NULL;
+    }
+}
+#endif
+
 void no_hash(db_line* line) {
-  line->attr&=~DB_HASHES;
+  line->attr&=~get_hashes(true);
 }
 
